@@ -1,4 +1,4 @@
-__version__ = '0.6'
+__version__ = '0.7'
 
 from os import access, R_OK
 from os.path import isfile
@@ -51,7 +51,7 @@ def parse_log(filename: str) -> List[Event]:
     Read a rsync log file and parses information.
     Returns a list of events (dictionary)
     """
-    global_pattern = r'(?P<timestamp>20[0-9][0-9] [A-Z][a-z]+\s+[0-9]{1,2}\s+[012][0-9]:[0-5][0-9]:[0-5][0-9])\s+\S+ rsyncd\[(?P<pid>[0-9]+)\]:(?P<logtype>(rsync (to|on)|sent)) ((?P<sentbytes>[0-9]+) bytes\s+received (?P<receivedbytes>[0-9]+) bytes\s+total size (?P<totalbytes>[0-9]+)|(?P<module>[-\w_]+)(?P<directory>\/\S*) from (?P<user>\S+)@(?P<hostname>\S+) \((?P<clientip>\S+)\))'
+    global_pattern = r'(?P<timestamp>20[0-9][0-9]-[0-9]{1,2}-[0-9]{1,2}\s+[012][0-9]:[0-5][0-9]:[0-5][0-9])\s+\S+ rsyncd\[(?P<pid>[0-9]+)\]: (?P<logtype>(rsync (to|on)|sent)) ((?P<sentbytes>[0-9]+) bytes\s+received (?P<receivedbytes>[0-9]+) bytes\s+total size (?P<totalbytes>[0-9]+)|(?P<module>[-\w_]+)(?P<directory>\/\S*) from (?P<user>\S+)@(?P<hostname>\S+) \((?P<clientip>\S+)\))'
     georeader = geolite2.reader()
     events = []
     events_buffer = {} # dict of events started but not ended. Key is the PID
@@ -65,7 +65,7 @@ def parse_log(filename: str) -> List[Event]:
             continue
         event_data = event.groupdict()
         # store time as epoch
-        event_data['timestamp'] = datetime.strptime(re.sub(' +', ' ', event_data['timestamp']), '%Y %b %d %H:%M:%S').strftime('%Y-%m-%d %H:%M:%S')
+        event_data['timestamp'] = event_data['timestamp']
         # 2 possible logs are captured by the pattern : connection log and transfer log.
         if event_data['logtype'] == 'rsync to' or event_data['logtype'] == 'rsync on':
             location = georeader.get(event_data['clientip'])
